/*-------------------------------------------------------------------------
 *
 *      Declarations of Peripheral I/O registers, I/O register bits,
 *      Interrupt/Exeption vectors for M32C/83 144-pin version.
 *
 *      This header file can be used by both the IAR M32C assembler
 *      (AM32C) and the M32C C compiler (ICCM32C).
 *
 *      Copyright 2001 IAR Systems. All rights reserved.
 *
 *      $Revision: 1.3 $
 *
 *-------------------------------------------------------------------------
 *
 *      This file, originally delivered from IAR, was corrected and modified
 *      by Segger Microcontroller Systeme GmbH
 *
 *      The following changes were made:
 *
 *      1.  U0C1 was defined at address 0x25d, corrected to 0x36D
 *      2.  All Baudrate generator registers renamed from UxBGR to UxBRG
 *          to be compatible to original Mitsubishi names and M16C80 defines
 *      3.  All UART transmit registers were also defined for byte access (UxTBL)
 *          to be compatible to original Mitsubishi names and M16C80 defines
 *      4.  All UART receive registers were also defined for byte access (UxRBL)
 *          to be compatible to original Mitsubishi names and M16C80 defines
 *
 *-------------------------------------------------------------------------*/

#ifndef __IOM32C_H__
#define __IOM32C_H__

#if ((__TID__ >> 8) & 0x7F) != 48
#error "IOM32C83_144.H file for use with AM32C/ICCM32C only"
#endif

#pragma language=extended

/***********************************************
 *       I/O register macros
 ***********************************************/

#include "iomacros.h"

#define fct_loc_1

/***********************************************
 *       Peripheral I/O register declarations
 ***********************************************/

/************************  Processor Registers  ***************************/

__IO_REG8( PM0,     0x000004, __READ_WRITE) // Processor Mode Register 0
__IO_REG8( PM1,     0x000005, __READ_WRITE) // Processor Mode Register 1
__IO_REG8( CM0,     0x000006, __READ_WRITE) // System clock control register 0
__IO_REG8( CM1,     0x000007, __READ_WRITE) // System clock control register 1
__IO_REG8( WCR,     0x000008, __READ_WRITE) // Wait control register
__IO_REG8( PRCR,    0x00000A, __READ_WRITE) // Protect register
__IO_REG8( DS,      0x00000B, __READ_WRITE) // External data bus width control register
__IO_REG8( MCD,     0x00000C, __READ_WRITE) // Main clock division register
__IO_REG8( DRAMCONT,0x000040, __READ_WRITE) // DRAM control register
__IO_REG8( REFCNT,  0x000041, __READ_WRITE) // DRAM refresh interval set register
__IO_REG8( CM2,     0x00000D, __READ_WRITE) // Oscillation stop detect register
__IO_REG8( PLV,     0x000017, __READ_WRITE) // VDC control register for PLL
__IO_REG8( PLC0,    0x000376, __READ_WRITE) // PLL control register 0
__IO_REG8( IPS,     0x000178, __READ_WRITE) // Input function select register

/************************  Emulation Control Registers  *******************/
/***************  THESE REGISTERS ARE NOT AVAILABLE FOR USERS *************/
__IO_REG8( VDC1,    0x00001B, __READ_WRITE) // VDC control register 1
__IO_REG8( VDC0,    0x00001F, __READ_WRITE) // VDC control register 0
__IO_REG32( EIAD0,  0x000020, __READ_WRITE) // Emulator interrupt vector table register
__IO_REG8( EIAD00,  0x000020, __READ_WRITE) // Emulator interrupt vector table register (low)
__IO_REG8( EIAD01,  0x000021, __READ_WRITE) // Emulator interrupt vector table register (mid)
__IO_REG8( EIAD02,  0x000022, __READ_WRITE) // Emulator interrupt vector table register (high)
__IO_REG8( EITD,    0x000023, __READ_WRITE) // Emulator interrupt detect register
__IO_REG8( EPRR,    0x000024, __READ_WRITE) // Emulator protect register
__IO_REG8( ROA,     0x000030, __READ_WRITE) // ROM area set register
__IO_REG8( DBA,     0x000031, __READ_WRITE) // Debug monitor area set register
__IO_REG8( EXA0,    0x000032, __READ_WRITE) // Expansion area set register 0
__IO_REG8( EXA1,    0x000033, __READ_WRITE) // Expansion area set register 1
__IO_REG8( EXA2,    0x000034, __READ_WRITE) // Expansion area set register 2
__IO_REG8( EXA3,    0x000035, __READ_WRITE) // Expansion area set register 3
__IO_REG8( FMR2,    0x000055, __READ_WRITE) // Flash memory control register 2
__IO_REG8( FMR1,    0x000056, __READ_WRITE) // Flash memory control register 1

/************************  Watchdog Timer  ********************************/
__IO_REG8( WDTS,    0x00000E, __READ_WRITE) // Watchdog timer start register
__IO_REG8( WDC,     0x00000F, __READ_WRITE) // Watchdog timer control register

/************************  Flash memory control register  *****************/
__IO_REG8( FMR0,    0x000057, __READ_WRITE) // Flash memory control register 0

/************************  Interrupt Control Register  ********************/
__IO_REG8( AIER,    0x000009, __READ_WRITE) // Address match interrupt control register
__IO_REG32( RMAD0,  0x000010, __READ_WRITE) // Address match interrupt register 0
__IO_REG8( RMAD00,  0x000010, __READ_WRITE) // Address match interrupt register 0 (low)
__IO_REG8( RMAD01,  0x000011, __READ_WRITE) // Address match interrupt register 0 (mid)
__IO_REG8( RMAD02,  0x000012, __READ_WRITE) // Address match interrupt register 0 (high)
__IO_REG32( RMAD1,  0x000014, __READ_WRITE) // Address match interrupt register 1
__IO_REG8( RMAD10,  0x000014, __READ_WRITE) // Address match interrupt register 1 (low)
__IO_REG8( RMAD11,  0x000015, __READ_WRITE) // Address match interrupt register 1 (mid)
__IO_REG8( RMAD12,  0x000016, __READ_WRITE) // Address match interrupt register 1 (high)
__IO_REG32( RMAD2,  0x000018, __READ_WRITE) // Address match interrupt register 2
__IO_REG8( RMAD20,  0x000018, __READ_WRITE) // Address match interrupt register 2 (low)
__IO_REG8( RMAD21,  0x000019, __READ_WRITE) // Address match interrupt register 2 (mid)
__IO_REG8( RMAD22,  0x00001A, __READ_WRITE) // Address match interrupt register 2 (high)
__IO_REG32( RMAD3,  0x00001C, __READ_WRITE) // Address match interrupt register 3
__IO_REG8( RMAD30,  0x00001C, __READ_WRITE) // Address match interrupt register 3 (low)
__IO_REG8( RMAD31,  0x00001D, __READ_WRITE) // Address match interrupt register 3 (mid)
__IO_REG8( RMAD32,  0x00001E, __READ_WRITE) // Address match interrupt register 3 (high)
__IO_REG8( DM0IC,   0x000068, __READ_WRITE) // DMA0 interrupt control register
__IO_REG8( DM1IC,   0x000088, __READ_WRITE) // DMA1 interrupt control register
__IO_REG8( DM2IC,   0x00006A, __READ_WRITE) // DMA2 interrupt control register
__IO_REG8( DM3IC,   0x00008A, __READ_WRITE) // DMA3 interrupt control register
__IO_REG8( KURIC,   0x000093, __READ_WRITE) // Key input interrupt control register
__IO_REG8( AD0IC,   0x000073, __READ_WRITE) // A-D0 interrupt control register
__IO_REG8( AD1IC,   0x000086, __READ_WRITE) // A-D1 interrupt control register
__IO_REG8( S0TIC,   0x000090, __READ_WRITE) // UART0 transmit/NACK interrupt control register
__IO_REG8( S0RIC,   0x000072, __READ_WRITE) // UART0 receive/ACK interrupt control register
__IO_REG8( BCN0IC,  0x000071, __READ_WRITE) // UART0/UART3 but collision detection interrupt control register
__IO_REG8( S1TIC,   0x000092, __READ_WRITE) // UART1 transmit/NACK interrupt control register
__IO_REG8( S1RIC,   0x000074, __READ_WRITE) // UART1 receive/ACK interrupt control register
__IO_REG8( BCN1IC,  0x000091, __READ_WRITE) // UART1/UART4 but collision detection interrupt control register
__IO_REG8( S2TIC,   0x000089, __READ_WRITE) // UART2 transmit/NACK interrupt control register
__IO_REG8( S2RIC,   0x00006B, __READ_WRITE) // UART2 receive/ACK interrupt control register
__IO_REG8( BCN2IC,  0x00008F, __READ_WRITE) // UART2 bus collision detection interrupt control register
__IO_REG8( S3TIC,   0x00008B, __READ_WRITE) // UART3 transmit/NACK interrupt control register
__IO_REG8( S3RIC,   0x00006D, __READ_WRITE) // UART3 receive/ACK interrupt control register
__IO_REG8( S4TIC,   0x00008D, __READ_WRITE) // UART4 transmit/NACK interrupt control register
__IO_REG8( S4RIC,   0x00006F, __READ_WRITE) // UART4 receive/ACK interrupt control register
__IO_REG8( TA0IC,   0x00006C, __READ_WRITE) // Timer A0 interrupt control register
__IO_REG8( TA1IC,   0x00008C, __READ_WRITE) // Timer A1 interrupt control register
__IO_REG8( TA2IC,   0x00006E, __READ_WRITE) // Timer A2 interrupt control register
__IO_REG8( TA3IC,   0x00008E, __READ_WRITE) // Timer A3 interrupt control register
__IO_REG8( TA4IC,   0x000070, __READ_WRITE) // Timer A4 interrupt control register
__IO_REG8( TB0IC,   0x000094, __READ_WRITE) // Timer B0 interrupt control register
__IO_REG8( TB1IC,   0x000076, __READ_WRITE) // Timer B1 interrupt control register
__IO_REG8( TB2IC,   0x000096, __READ_WRITE) // Timer B2 interrupt control register
__IO_REG8( TB3IC,   0x000078, __READ_WRITE) // Timer B3 interrupt control register
__IO_REG8( TB4IC,   0x000098, __READ_WRITE) // Timer B4 interrupt control register
__IO_REG8( TB5IC,   0x000069, __READ_WRITE) // Timer B5 interrupt control register
__IO_REG8( INT0IC,  0x00009E, __READ_WRITE) // Interrupt 0 interrupt control register
__IO_REG8( INT1IC,  0x00007E, __READ_WRITE) // Interrupt 1 interrupt control register
__IO_REG8( INT2IC,  0x00009C, __READ_WRITE) // Interrupt 2 interrupt control register
__IO_REG8( INT3IC,  0x00007C, __READ_WRITE) // Interrupt 3 interrupt control register
__IO_REG8( INT4IC,  0x00009A, __READ_WRITE) // Interrupt 4 interrupt control register
__IO_REG8( INT5IC,  0x00007A, __READ_WRITE) // Interrupt 5 interrupt control register
__IO_REG8( IIO0IC,  0x000075, __READ_WRITE) // Intelligent I/O interrupt control register 0
__IO_REG8( IIO1IC,  0x000095, __READ_WRITE) // Intelligent I/O interrupt control register 1
__IO_REG8( IIO2IC,  0x000077, __READ_WRITE) // Intelligent I/O interrupt control register 2
__IO_REG8( IIO3IC,  0x000097, __READ_WRITE) // Intelligent I/O interrupt control register 3
__IO_REG8( IIO4IC,  0x000079, __READ_WRITE) // Intelligent I/O interrupt control register 4
__IO_REG8( IIO5IC,  0x000099, __READ_WRITE) // Intelligent I/O interrupt control register 5
__IO_REG8( IIO6IC,  0x00007B, __READ_WRITE) // Intelligent I/O interrupt control register 6
__IO_REG8( IIO7IC,  0x00009B, __READ_WRITE) // Intelligent I/O interrupt control register 7
__IO_REG8( IIO8IC,  0x00007D, __READ_WRITE) // Intelligent I/O interrupt control register 8
__IO_REG8( IIO9IC,  0x00009D, __READ_WRITE) // Intelligent I/O interrupt control register 9
__IO_REG8( IIO10IC, 0x00007F, __READ_WRITE) // Intelligent I/O interrupt control register 10
__IO_REG8( IIO11IC, 0x000081, __READ_WRITE) // Intelligent I/O interrupt control register 11
__IO_REG8( IIO0IR,  0x0000A0, __READ_WRITE) // Interrupt request register 0
__IO_REG8( IIO1IR,  0x0000A1, __READ_WRITE) // Interrupt request register 1
__IO_REG8( IIO2IR,  0x0000A2, __READ_WRITE) // Interrupt request register 2
__IO_REG8( IIO3IR,  0x0000A3, __READ_WRITE) // Interrupt request register 3
__IO_REG8( IIO4IR,  0x0000A4, __READ_WRITE) // Interrupt request register 4
__IO_REG8( IIO5IR,  0x0000A5, __READ_WRITE) // Interrupt request register 5
__IO_REG8( IIO6IR,  0x0000A6, __READ_WRITE) // Interrupt request register 6
__IO_REG8( IIO7IR,  0x0000A7, __READ_WRITE) // Interrupt request register 7
__IO_REG8( IIO8IR,  0x0000A8, __READ_WRITE) // Interrupt request register 8
__IO_REG8( IIO9IR,  0x0000A9, __READ_WRITE) // Interrupt request register 9
__IO_REG8( IIO10IR, 0x0000AA, __READ_WRITE) // Interrupt request register 10
__IO_REG8( IIO11IR, 0x0000AB, __READ_WRITE) // Interrupt request register 11
__IO_REG8( IIO0IE,  0x0000B0, __READ_WRITE) // Interrupt enable register 0
__IO_REG8( IIO1IE,  0x0000B1, __READ_WRITE) // Interrupt enable register 1
__IO_REG8( IIO2IE,  0x0000B2, __READ_WRITE) // Interrupt enable register 2
__IO_REG8( IIO3IE,  0x0000B3, __READ_WRITE) // Interrupt enable register 3
__IO_REG8( IIO4IE,  0x0000B4, __READ_WRITE) // Interrupt enable register 4
__IO_REG8( IIO5IE,  0x0000B5, __READ_WRITE) // Interrupt enable register 5
__IO_REG8( IIO6IE,  0x0000B6, __READ_WRITE) // Interrupt enable register 6
__IO_REG8( IIO7IE,  0x0000B7, __READ_WRITE) // Interrupt enable register 7
__IO_REG8( IIO8IE,  0x0000B8, __READ_WRITE) // Interrupt enable register 8
__IO_REG8( IIO9IE,  0x0000B9, __READ_WRITE) // Interrupt enable register 9
__IO_REG8( IIO10IE, 0x0000BA, __READ_WRITE) // Interrupt enable register 10
__IO_REG8( IIO11IE, 0x0000BB, __READ_WRITE) // Interrupt enable register 11
__IO_REG8( RLVL,    0x00009F, __READ_WRITE) // EXIT priority control register
__IO_REG8( IFSR,    0x00031F, __READ_WRITE) // External interrupt cause select register

/************************  Group 0 Register  ******************************/
__IO_REG16(G0TM0,   0x0000C0, __READ_WRITE) // Group 0 TM register 0
__IO_REG16(G0PO0,   0x0000C0, __READ_WRITE) // Group 0 WG register 0
__IO_REG16(G0TM1,   0x0000C2, __READ_WRITE) // Group 0 TM register 1
__IO_REG16(G0PO1,   0x0000C2, __READ_WRITE) // Group 0 WG register 1
__IO_REG16(G0TM2,   0x0000C4, __READ_WRITE) // Group 0 TM register 2
__IO_REG16(G0PO2,   0x0000C4, __READ_WRITE) // Group 0 WG register 2
__IO_REG16(G0TM3,   0x0000C6, __READ_WRITE) // Group 0 TM register 3
__IO_REG16(G0PO3,   0x0000C6, __READ_WRITE) // Group 0 WG register 3
__IO_REG16(G0TM4,   0x0000C8, __READ_WRITE) // Group 0 TM register 4
__IO_REG16(G0PO4,   0x0000C8, __READ_WRITE) // Group 0 WG register 4
__IO_REG16(G0TM5,   0x0000CA, __READ_WRITE) // Group 0 TM register 5
__IO_REG16(G0PO5,   0x0000CA, __READ_WRITE) // Group 0 WG register 5
__IO_REG16(G0TM6,   0x0000CC, __READ_WRITE) // Group 0 TM register 6
__IO_REG16(G0PO6,   0x0000CC, __READ_WRITE) // Group 0 WG register 6
__IO_REG16(G0TM7,   0x0000CE, __READ_WRITE) // Group 0 TM register 7
__IO_REG16(G0PO7,   0x0000CE, __READ_WRITE) // Group 0 WG register 7
__IO_REG8( G0POCR0, 0x0000D0, __READ_WRITE) // Group 0 waveform generate control register 0
__IO_REG8( G0POCR1, 0x0000D1, __READ_WRITE) // Group 0 waveform generate control register 1
__IO_REG8( G0POCR2, 0x0000D2, __READ_WRITE) // Group 0 waveform generate control register 2
__IO_REG8( G0POCR3, 0x0000D3, __READ_WRITE) // Group 0 waveform generate control register 3
__IO_REG8( G0POCR4, 0x0000D4, __READ_WRITE) // Group 0 waveform generate control register 4
__IO_REG8( G0POCR5, 0x0000D5, __READ_WRITE) // Group 0 waveform generate control register 5
__IO_REG8( G0POCR6, 0x0000D6, __READ_WRITE) // Group 0 waveform generate control register 6
__IO_REG8( G0POCR7, 0x0000D7, __READ_WRITE) // Group 0 waveform generate control register 7
__IO_REG8( G0TMCR0, 0x0000D8, __READ_WRITE) // Group 0 time measurement control register 0
__IO_REG8( G0TMCR1, 0x0000D9, __READ_WRITE) // Group 0 time measurement control register 1
__IO_REG8( G0TMCR2, 0x0000DA, __READ_WRITE) // Group 0 time measurement control register 2
__IO_REG8( G0TMCR3, 0x0000DB, __READ_WRITE) // Group 0 time measurement control register 3
__IO_REG8( G0TMCR4, 0x0000DC, __READ_WRITE) // Group 0 time measurement control register 4
__IO_REG8( G0TMCR5, 0x0000DD, __READ_WRITE) // Group 0 time measurement control register 5
__IO_REG8( G0TMCR6, 0x0000DE, __READ_WRITE) // Group 0 time measurement control register 6
__IO_REG8( G0TMCR7, 0x0000DF, __READ_WRITE) // Group 0 time measurement control register 7
__IO_REG16(G0BT,    0x0000E0, __READ_WRITE) // Group 0 base timer register
__IO_REG8( G0BCR0,  0x0000E2, __READ_WRITE) // Group 0 base timer control register 0
__IO_REG8( G0BCR1,  0x0000E3, __READ_WRITE) // Group 0 base timer control register 1
__IO_REG8( G0TPR6,  0x0000E4, __READ_WRITE) // Group 0 time measurement prescaler register 6
__IO_REG8( G0TPR7,  0x0000E5, __READ_WRITE) // Group 0 time measurement prescaler register 7
__IO_REG8( G0FE,    0x0000E6, __READ_WRITE) // Group 0 function enable register
__IO_REG8( G0FS,    0x0000E7, __READ_WRITE) // Group 0 function select register
__IO_REG16(G0BF,    0x0000E8, __READ_WRITE) // Group 0 SI/O receive buffer register
__IO_REG8( G0DR,    0x0000EA, __READ_WRITE) // Group 0 transmit buffer/receive data register
__IO_REG8( G0RI,    0x0000EC, __READ_WRITE) // Group 0 receive input register
__IO_REG8( G0MR,    0x0000ED, __READ_WRITE) // Group 0 communication mode register
__IO_REG8( G0TO,    0x0000EE, __READ_WRITE) // Group 0 transmit output register
__IO_REG8( G0CR,    0x0000EF, __READ_WRITE) // Group 0 SI/O communication control register
__IO_REG8( G0CMP0,  0x0000F0, __READ_WRITE) // Group 0 data compare register 0
__IO_REG8( G0CMP1,  0x0000F1, __READ_WRITE) // Group 0 data compare register 1
__IO_REG8( G0CMP2,  0x0000F2, __READ_WRITE) // Group 0 data compare register 2
__IO_REG8( G0CMP3,  0x0000F3, __READ_WRITE) // Group 0 data compare register 3
__IO_REG8( G0MSK0,  0x0000F4, __READ_WRITE) // Group 0 data mask register 0
__IO_REG8( G0MSK1,  0x0000F5, __READ_WRITE) // Group 0 data mask register 1
__IO_REG16(G0RCRC,  0x0000F8, __READ_WRITE) // Group 0 receive CRC code register
__IO_REG16(G0TCRC,  0x0000FA, __READ_WRITE) // Group 0 transmit CRC code register
__IO_REG8( G0EMR,   0x0000FC, __READ_WRITE) // Group 0 SI/O expansion mode register
__IO_REG8( G0ERC,   0x0000FD, __READ_WRITE) // Group 0 SI/O expansion receive control register
__IO_REG8( G0IRF,   0x0000FE, __READ_WRITE) // Group 0 SI/O special communication interrupt detect register
__IO_REG8( G0ETC,   0x0000FF, __READ_WRITE) // Group 0 SI/O expansion transmit control register

/************************  Group 1 Register  ******************************/
__IO_REG16(G1TM0,   0x000100, __READ_WRITE) // Group 1 TM register 0
__IO_REG16(G1PO0,   0x000100, __READ_WRITE) // Group 1 WG register 0
__IO_REG16(G1TM1,   0x000102, __READ_WRITE) // Group 1 TM register 1
__IO_REG16(G1PO1,   0x000102, __READ_WRITE) // Group 1 WG register 1
__IO_REG16(G1TM2,   0x000104, __READ_WRITE) // Group 1 TM register 2
__IO_REG16(G1PO2,   0x000104, __READ_WRITE) // Group 1 WG register 2
__IO_REG16(G1TM3,   0x000106, __READ_WRITE) // Group 1 TM register 3
__IO_REG16(G1PO3,   0x000106, __READ_WRITE) // Group 1 WG register 3
__IO_REG16(G1TM4,   0x000108, __READ_WRITE) // Group 1 TM register 4
__IO_REG16(G1PO4,   0x000108, __READ_WRITE) // Group 1 WG register 4
__IO_REG16(G1TM5,   0x00010A, __READ_WRITE) // Group 1 TM register 5
__IO_REG16(G1PO5,   0x00010A, __READ_WRITE) // Group 1 WG register 5
__IO_REG16(G1TM6,   0x00010C, __READ_WRITE) // Group 1 TM register 6
__IO_REG16(G1PO6,   0x00010C, __READ_WRITE) // Group 1 WG register 6
__IO_REG16(G1TM7,   0x00010E, __READ_WRITE) // Group 1 TM register 7
__IO_REG16(G1PO7,   0x00010E, __READ_WRITE) // Group 1 WG register 7
__IO_REG8( G1POCR0, 0x000110, __READ_WRITE) // Group 1 waveform generate control register 0
__IO_REG8( G1POCR1, 0x000111, __READ_WRITE) // Group 1 waveform generate control register 1
__IO_REG8( G1POCR2, 0x000112, __READ_WRITE) // Group 1 waveform generate control register 2
__IO_REG8( G1POCR3, 0x000113, __READ_WRITE) // Group 1 waveform generate control register 3
__IO_REG8( G1POCR4, 0x000114, __READ_WRITE) // Group 1 waveform generate control register 4
__IO_REG8( G1POCR5, 0x000115, __READ_WRITE) // Group 1 waveform generate control register 5
__IO_REG8( G1POCR6, 0x000116, __READ_WRITE) // Group 1 waveform generate control register 6
__IO_REG8( G1POCR7, 0x000117, __READ_WRITE) // Group 1 waveform generate control register 7
__IO_REG8( G1TMCR0, 0x000118, __READ_WRITE) // Group 1 time measurement control register 0
__IO_REG8( G1TMCR1, 0x000119, __READ_WRITE) // Group 1 time measurement control register 1
__IO_REG8( G1TMCR2, 0x00011A, __READ_WRITE) // Group 1 time measurement control register 2
__IO_REG8( G1TMCR3, 0x00011B, __READ_WRITE) // Group 1 time measurement control register 3
__IO_REG8( G1TMCR4, 0x00011C, __READ_WRITE) // Group 1 time measurement control register 4
__IO_REG8( G1TMCR5, 0x00011D, __READ_WRITE) // Group 1 time measurement control register 5
__IO_REG8( G1TMCR6, 0x00011E, __READ_WRITE) // Group 1 time measurement control register 6
__IO_REG8( G1TMCR7, 0x00011F, __READ_WRITE) // Group 1 time measurement control register 7
__IO_REG16(G1BT,    0x000120, __READ_WRITE) // Group 1 base timer register
__IO_REG8( G1BCR0,  0x000122, __READ_WRITE) // Group 1 base timer control register 0
__IO_REG8( G1BCR1,  0x000123, __READ_WRITE) // Group 1 base timer control register 1
__IO_REG8( G1TPR6,  0x000124, __READ_WRITE) // Group 1 time measurement prescaler register 6
__IO_REG8( G1TPR7,  0x000125, __READ_WRITE) // Group 1 time measurement prescaler register 7
__IO_REG8( G1FE,    0x000126, __READ_WRITE) // Group 1 function enable register
__IO_REG8( G1FS,    0x000127, __READ_WRITE) // Group 1 function select register
__IO_REG16(G1BF,    0x000128, __READ_WRITE) // Group 1 SI/O receive buffer register
__IO_REG8( G1DR,    0x00012A, __READ_WRITE) // Group 1 transmit buffer/receive data register
__IO_REG8( G1RI,    0x00012C, __READ_WRITE) // Group 1 receive input register
__IO_REG8( G1MR,    0x00012D, __READ_WRITE) // Group 1 communication mode register
__IO_REG8( G1TO,    0x00012E, __READ_WRITE) // Group 1 transmit output register
__IO_REG8( G1CR,    0x00012F, __READ_WRITE) // Group 1 SI/O communication control register
__IO_REG8( G1CMP0,  0x000130, __READ_WRITE) // Group 1 data compare register 0
__IO_REG8( G1CMP1,  0x000131, __READ_WRITE) // Group 1 data compare register 1
__IO_REG8( G1CMP2,  0x000132, __READ_WRITE) // Group 1 data compare register 2
__IO_REG8( G1CMP3,  0x000133, __READ_WRITE) // Group 1 data compare register 3
__IO_REG8( G1MSK0,  0x000134, __READ_WRITE) // Group 1 data mask register 0
__IO_REG8( G1MSK1,  0x000135, __READ_WRITE) // Group 1 data mask register 1
__IO_REG16(G1RCRC,  0x000138, __READ_WRITE) // Group 1 receive CRC code register
__IO_REG16(G1TCRC,  0x00013A, __READ_WRITE) // Group 1 transmit CRC code register
__IO_REG8( G1EMR,   0x00013C, __READ_WRITE) // Group 1 SI/O expansion mode register
__IO_REG8( G1ERC,   0x00013D, __READ_WRITE) // Group 1 SI/O expansion receive control register
__IO_REG8( G1IRF,   0x00013E, __READ_WRITE) // Group 1 SI/O special communication interrupt detect register
__IO_REG8( G1ETC,   0x00013F, __READ_WRITE) // Group 1 SI/O expansion transmit control register

/************************  Group 2 Register  ******************************/
__IO_REG16(G2PO0,   0x000140, __READ_WRITE) // Group 2 WG register 0
__IO_REG16(G2PO1,   0x000142, __READ_WRITE) // Group 2 WG register 1
__IO_REG16(G2PO2,   0x000144, __READ_WRITE) // Group 2 WG register 2
__IO_REG16(G2PO3,   0x000146, __READ_WRITE) // Group 2 WG register 3
__IO_REG16(G2PO4,   0x000148, __READ_WRITE) // Group 2 WG register 4
__IO_REG16(G2PO5,   0x00014A, __READ_WRITE) // Group 2 WG register 5
__IO_REG16(G2PO6,   0x00014C, __READ_WRITE) // Group 2 WG register 6
__IO_REG16(G2PO7,   0x00014E, __READ_WRITE) // Group 2 WG register 7
__IO_REG8( G2POCR0, 0x000150, __READ_WRITE) // Group 2 waveform generate control register 0
__IO_REG8( G2POCR1, 0x000151, __READ_WRITE) // Group 2 waveform generate control register 1
__IO_REG8( G2POCR2, 0x000152, __READ_WRITE) // Group 2 waveform generate control register 2
__IO_REG8( G2POCR3, 0x000153, __READ_WRITE) // Group 2 waveform generate control register 3
__IO_REG8( G2POCR4, 0x000154, __READ_WRITE) // Group 2 waveform generate control register 4
__IO_REG8( G2POCR5, 0x000155, __READ_WRITE) // Group 2 waveform generate control register 5
__IO_REG8( G2POCR6, 0x000156, __READ_WRITE) // Group 2 waveform generate control register 6
__IO_REG8( G2POCR7, 0x000157, __READ_WRITE) // Group 2 waveform generate control register 7
__IO_REG16(G2BT,    0x000160, __READ_WRITE) // Group 2 base timer register
__IO_REG8( G2BCR0,  0x000162, __READ_WRITE) // Group 2 base timer control register 0
__IO_REG8( G2BCR1,  0x000163, __READ_WRITE) // Group 2 base timer control register 1
__IO_REG8( G2FE,    0x000166, __READ_WRITE) // Group 2 function enable register
__IO_REG8( G2RTP,   0x000167, __READ_WRITE) // Group 2 RTP output buffer register
__IO_REG8( G2MR,    0x00016A, __READ_WRITE) // Group 2 SI/O communication mode register
__IO_REG8( G2CR,    0x00016B, __READ_WRITE) // Group 2 SI/O communication control register
__IO_REG16(G2TB,    0x00016C, __READ_WRITE) // Group 2 SI/O transmit buffer register
__IO_REG16(G2RB,    0x00016E, __READ_WRITE) // Group 2 SI/O receive buffer register
__IO_REG16(IEAR,    0x000170, __READ_WRITE) // Group 2 IEBus address register
__IO_REG8( IECR,    0x000172, __READ_WRITE) // Group 2 IEBus control register
__IO_REG8( IETIF,   0x000173, __READ_WRITE) // Group 2 IEBus transmit interrupt cause detect register
__IO_REG8( IERIF,   0x000174, __READ_WRITE) // Group 2 IEBus receive interrupt cause detect register

/************************  Group 3 Register  ******************************/
__IO_REG16(G3PO0,   0x000180, __READ_WRITE) // Group 3 WG register 0
__IO_REG16(G3PO1,   0x000182, __READ_WRITE) // Group 3 WG register 1
__IO_REG16(G3PO2,   0x000184, __READ_WRITE) // Group 3 WG register 2
__IO_REG16(G3PO3,   0x000186, __READ_WRITE) // Group 3 WG register 3
__IO_REG16(G3PO4,   0x000188, __READ_WRITE) // Group 3 WG register 4
__IO_REG16(G3PO5,   0x00018A, __READ_WRITE) // Group 3 WG register 5
__IO_REG16(G3PO6,   0x00018C, __READ_WRITE) // Group 3 WG register 6
__IO_REG16(G3PO7,   0x00018E, __READ_WRITE) // Group 3 WG register 7
__IO_REG8( G3POCR0, 0x000190, __READ_WRITE) // Group 3 waveform generate control register 0
__IO_REG8( G3POCR1, 0x000191, __READ_WRITE) // Group 3 waveform generate control register 1
__IO_REG8( G3POCR2, 0x000192, __READ_WRITE) // Group 3 waveform generate control register 2
__IO_REG8( G3POCR3, 0x000193, __READ_WRITE) // Group 3 waveform generate control register 3
__IO_REG8( G3POCR4, 0x000194, __READ_WRITE) // Group 3 waveform generate control register 4
__IO_REG8( G3POCR5, 0x000195, __READ_WRITE) // Group 3 waveform generate control register 5
__IO_REG8( G3POCR6, 0x000196, __READ_WRITE) // Group 3 waveform generate control register 6
__IO_REG8( G3POCR7, 0x000197, __READ_WRITE) // Group 3 waveform generate control register 7
__IO_REG16(G3BT,    0x0001A0, __READ_WRITE) // Group 3 base timer register
__IO_REG8( G3BCR0,  0x0001A2, __READ_WRITE) // Group 3 base timer control register 0
__IO_REG8( G3BCR1,  0x0001A3, __READ_WRITE) // Group 3 base timer control register 1
__IO_REG8( G3MR,    0x00017A, __READ_WRITE) // Group 3 SI/O communication mode register
__IO_REG8( G3CR,    0x00017B, __READ_WRITE) // Group 3 SI/O communication control register
__IO_REG16(G3TB,    0x00017C, __READ_WRITE) // Group 3 SI/O transmit buffer register
__IO_REG16(G3RB,    0x00017E, __READ_WRITE) // Group 3 SI/O receive buffer register
__IO_REG16(G3MK4,   0x000198, __READ_WRITE) // Group 3 WG mask register 4
__IO_REG16(G3MK5,   0x00019A, __READ_WRITE) // Group 3 WG mask register 5
__IO_REG16(G3MK6,   0x00019C, __READ_WRITE) // Group 3 WG mask register 6
__IO_REG16(G3MK7,   0x00019E, __READ_WRITE) // Group 3 WG mask register 7
__IO_REG8( G3FE,    0x0001A6, __READ_WRITE) // Group 3 function enable register
__IO_REG8( G3RTP,   0x0001A7, __READ_WRITE) // Group 3 RTP output buffer register
__IO_REG8( HDLC1,   0x0001AB, __READ_WRITE) // Group 3 high-speed HDLC communication control register 1
__IO_REG8( HDLC,    0x0001AC, __READ_WRITE) // Group 3 high-speed HDLC communication control register
__IO_REG8( HDLCF,   0x0001AD, __READ_WRITE) // Group 3 high-speed HDLC communication register
__IO_REG16(HDLCC,   0x0001AE, __READ_WRITE) // Group 3 high-speed HDLC transmit counter
__IO_REG16(HDLCCP0, 0x0001B0, __READ_WRITE) // Group 3 high-speed HDLC data compare register 0
__IO_REG16(HDLCMK0, 0x0001B2, __READ_WRITE) // Group 3 high-speed HDLC data mask register 0
__IO_REG16(HDLCCP1, 0x0001B4, __READ_WRITE) // Group 3 high-speed HDLC data compare register 1
__IO_REG16(HDLCMK1, 0x0001B6, __READ_WRITE) // Group 3 high-speed HDLC data mask register 1
__IO_REG16(HDLCCP2, 0x0001B8, __READ_WRITE) // Group 3 high-speed HDLC data compare register 1
__IO_REG16(HDLCMK2, 0x0001BA, __READ_WRITE) // Group 3 high-speed HDLC data mask register 1
__IO_REG16(HDLCCP3, 0x0001BC, __READ_WRITE) // Group 3 high-speed HDLC data compare register 1
__IO_REG16(HDLCMK3, 0x0001BE, __READ_WRITE) // Group 3 high-speed HDLC data mask register 1

/************************  A-D Converter  *********************************/
__IO_REG16(AD00,    0x000380, __READ_WRITE) // A-D0 register 0
__IO_REG16(AD01,    0x000382, __READ_WRITE) // A-D0 register 1
__IO_REG16(AD02,    0x000384, __READ_WRITE) // A-D0 register 2
__IO_REG16(AD03,    0x000386, __READ_WRITE) // A-D0 register 3
__IO_REG16(AD04,    0x000388, __READ_WRITE) // A-D0 register 4
__IO_REG16(AD05,    0x00038A, __READ_WRITE) // A-D0 register 5
__IO_REG16(AD06,    0x00038C, __READ_WRITE) // A-D0 register 6
__IO_REG16(AD07,    0x00038E, __READ_WRITE) // A-D0 register 7
__IO_REG8( AD0CON0, 0x000396, __READ_WRITE) // A-D0 control register 0
__IO_REG8( AD0CON1, 0x000397, __READ_WRITE) // A-D0 control register 1
__IO_REG8( AD0CON2, 0x000394, __READ_WRITE) // A-D0 control register 2

__IO_REG16(AD10,    0x0001C0, __READ_WRITE) // A-D1 register 0
__IO_REG16(AD11,    0x0001C2, __READ_WRITE) // A-D1 register 1
__IO_REG16(AD12,    0x0001C4, __READ_WRITE) // A-D1 register 2
__IO_REG16(AD13,    0x0001C6, __READ_WRITE) // A-D1 register 3
__IO_REG16(AD14,    0x0001C8, __READ_WRITE) // A-D1 register 4
__IO_REG16(AD15,    0x0001CA, __READ_WRITE) // A-D1 register 5
__IO_REG16(AD16,    0x0001CC, __READ_WRITE) // A-D1 register 6
__IO_REG16(AD17,    0x0001CE, __READ_WRITE) // A-D1 register 7
__IO_REG8( AD1CON0, 0x0001D6, __READ_WRITE) // A-D1 control register 0
__IO_REG8( AD1CON1, 0x0001D7, __READ_WRITE) // A-D1 control register 1
__IO_REG8( AD1CON2, 0x0001D4, __READ_WRITE) // A-D1 control register 2

/************************  D-A Converter  *********************************/
__IO_REG8( DA0,     0x000398, __READ_WRITE) // D-A register 0
__IO_REG8( DA1,     0x00039A, __READ_WRITE) // D-A register 1
__IO_REG8( DACON,   0x00039C, __READ_WRITE) // D-A control register

/************************  CAN0 register **********************************/
__IO_REG8(C0SLOT0_0,  0x0001E0, __READ_WRITE) // CAN0 message slot buffer 0 standard ID0
__IO_REG8(C0SLOT0_1,  0x0001E1, __READ_WRITE) // CAN0 message slot buffer 0 standard ID1
__IO_REG8(C0SLOT0_2,  0x0001E2, __READ_WRITE) // CAN0 message slot buffer 0 extend ID0
__IO_REG8(C0SLOT0_3,  0x0001E3, __READ_WRITE) // CAN0 message slot buffer 0 extend ID1
__IO_REG8(C0SLOT0_4,  0x0001E4, __READ_WRITE) // CAN0 message slot buffer 0 extend ID2
__IO_REG8(C0SLOT0_5,  0x0001E5, __READ_WRITE) // CAN0 message slot buffer 0 data length code
__IO_REG8(C0SLOT0_6,  0x0001E6, __READ_WRITE) // CAN0 message slot buffer 0 data 0
__IO_REG8(C0SLOT0_7,  0x0001E7, __READ_WRITE) // CAN0 message slot buffer 0 data 1
__IO_REG8(C0SLOT0_8,  0x0001E8, __READ_WRITE) // CAN0 message slot buffer 0 data 2
__IO_REG8(C0SLOT0_9,  0x0001E9, __READ_WRITE) // CAN0 message slot buffer 0 data 3
__IO_REG8(C0SLOT0_10, 0x0001EA, __READ_WRITE) // CAN0 message slot buffer 0 data 4
__IO_REG8(C0SLOT0_11, 0x0001EB, __READ_WRITE) // CAN0 message slot buffer 0 data 5
__IO_REG8(C0SLOT0_12, 0x0001EC, __READ_WRITE) // CAN0 message slot buffer 0 data 6
__IO_REG8(C0SLOT0_13, 0x0001ED, __READ_WRITE) // CAN0 message slot buffer 0 data 7
__IO_REG8(C0SLOT0_14, 0x0001EE, __READ_WRITE) // CAN0 message slot buffer 0 time stamp high
__IO_REG8(C0SLOT0_15, 0x0001EF, __READ_WRITE) // CAN0 message slot buffer 0 time stamp low
__IO_REG8(C0SLOT1_0,  0x0001F0, __READ_WRITE) // CAN0 message slot buffer 1 standard ID0
__IO_REG8(C0SLOT1_1,  0x0001F1, __READ_WRITE) // CAN0 message slot buffer 1 standard ID1
__IO_REG8(C0SLOT1_2,  0x0001F2, __READ_WRITE) // CAN0 message slot buffer 1 extend ID0
__IO_REG8(C0SLOT1_3,  0x0001F3, __READ_WRITE) // CAN0 message slot buffer 1 extend ID1
__IO_REG8(C0SLOT1_4,  0x0001F4, __READ_WRITE) // CAN0 message slot buffer 1 extend ID2
__IO_REG8(C0SLOT1_5,  0x0001F5, __READ_WRITE) // CAN0 message slot buffer 1 data length code
__IO_REG8(C0SLOT1_6,  0x0001F6, __READ_WRITE) // CAN0 message slot buffer 1 data 0
__IO_REG8(C0SLOT1_7,  0x0001F7, __READ_WRITE) // CAN0 message slot buffer 1 data 1
__IO_REG8(C0SLOT1_8,  0x0001F8, __READ_WRITE) // CAN0 message slot buffer 1 data 2
__IO_REG8(C0SLOT1_9,  0x0001F9, __READ_WRITE) // CAN0 message slot buffer 1 data 3
__IO_REG8(C0SLOT1_10, 0x0001FA, __READ_WRITE) // CAN0 message slot buffer 1 data 4
__IO_REG8(C0SLOT1_11, 0x0001FB, __READ_WRITE) // CAN0 message slot buffer 1 data 5
__IO_REG8(C0SLOT1_12, 0x0001FC, __READ_WRITE) // CAN0 message slot buffer 1 data 6
__IO_REG8(C0SLOT1_13, 0x0001FD, __READ_WRITE) // CAN0 message slot buffer 1 data 7
__IO_REG8(C0SLOT1_14, 0x0001FE, __READ_WRITE) // CAN0 message slot buffer 1 time stamp high
__IO_REG8(C0SLOT1_15, 0x0001FF, __READ_WRITE) // CAN0 message slot buffer 1 time stamp low
__IO_REG16(C0CTLR0,   0x000200, __READ_WRITE) // CAN0 control register 0
__IO_REG16(C0STR,     0x000202, __READ_WRITE) // CAN0 status register
__IO_REG16(C0IDR,     0x000204, __READ_WRITE) // CAN0 expansion ID register
__IO_REG16(C0CONR,    0x000206, __READ_WRITE) // CAN0 configuration register
__IO_REG16(C0TSR,     0x000208, __READ_WRITE) // CAN0 time stump register
__IO_REG8(C0TEC,      0x00020A, __READ_WRITE) // CAN0 transmit error count register
__IO_REG8(C0REC,      0x00020B, __READ_WRITE) // CAN0 receive error count register
__IO_REG16(C0SISTR,   0x00020C, __READ_WRITE) // CAN0 slot interrupt status register
__IO_REG16(C0SIMKR,   0x000210, __READ_WRITE) // CAN0 slot interrupt mask register
__IO_REG8(C0EIMKR,    0x000213, __READ_WRITE) // CAN0 error interrupt mask register
__IO_REG8(C0EISTR,    0x000214, __READ_WRITE) // CAN0 error interrupt status register
__IO_REG8(C0BPR,      0x000217, __READ_WRITE) // CAN0 baud rate prescaler
__IO_REG8(C0GMR0,     0x000228, __READ_WRITE) // CAN0 global mask register standard ID0
__IO_REG8(C0GMR1,     0x000229, __READ_WRITE) // CAN0 global mask register standard ID1
__IO_REG8(C0GMR2,     0x00022A, __READ_WRITE) // CAN0 global mask register extend ID0
__IO_REG8(C0GMR3,     0x00022B, __READ_WRITE) // CAN0 global mask register extend ID1
__IO_REG8(C0GMR4,     0x00022C, __READ_WRITE) // CAN0 global mask register extend ID2
__IO_REG8(COMCTL0,    0x000230, __READ_WRITE) // CAN0 message slot 0 control register
__IO_REG8(COMCTL1,    0x000231, __READ_WRITE) // CAN0 message slot 1 control register
__IO_REG8(COMCTL2,    0x000232, __READ_WRITE) // CAN0 message slot 2 control register
__IO_REG8(COMCTL3,    0x000233, __READ_WRITE) // CAN0 message slot 3 control register
__IO_REG8(COMCTL4,    0x000234, __READ_WRITE) // CAN0 message slot 4 control register
__IO_REG8(COMCTL5,    0x000235, __READ_WRITE) // CAN0 message slot 5 control register
__IO_REG8(COMCTL6,    0x000236, __READ_WRITE) // CAN0 message slot 6 control register
__IO_REG8(COMCTL7,    0x000237, __READ_WRITE) // CAN0 message slot 7 control register
__IO_REG8(COMCTL8,    0x000238, __READ_WRITE) // CAN0 message slot 8 control register
__IO_REG8(COMCTL9,    0x000239, __READ_WRITE) // CAN0 message slot 9 control register
__IO_REG8(COMCTL10,    0x00023A, __READ_WRITE) // CAN0 message slot 10 control register
__IO_REG8(COMCTL11,    0x00023B, __READ_WRITE) // CAN0 message slot 11 control register
__IO_REG8(COMCTL12,    0x00023C, __READ_WRITE) // CAN0 message slot 12 control register
__IO_REG8(COMCTL13,    0x00023D, __READ_WRITE) // CAN0 message slot 13 control register
__IO_REG8(COMCTL14,    0x00023E, __READ_WRITE) // CAN0 message slot 14 control register
__IO_REG8(COMCTL15,    0x00023F, __READ_WRITE) // CAN0 message slot 15 control register
__IO_REG8(COMLAR0,    0x000230, __READ_WRITE) // CAN0 local mask register A standard ID0
__IO_REG8(COMLAR1,    0x000231, __READ_WRITE) // CAN0 local mask register A standard ID1
__IO_REG8(COMLAR2,    0x000232, __READ_WRITE) // CAN0 local mask register A extend ID0
__IO_REG8(COMLAR3,    0x000233, __READ_WRITE) // CAN0 local mask register A extend ID1
__IO_REG8(COMLAR4,    0x000234, __READ_WRITE) // CAN0 local mask register A extend ID2
__IO_REG8(COLMBR0,    0x000238, __READ_WRITE) // CAN0 local mask register B standard ID0
__IO_REG8(COLMBR1,    0x000239, __READ_WRITE) // CAN0 local mask register B standard ID1
__IO_REG8(COMLBR2,    0x00023A, __READ_WRITE) // CAN0 local mask register B extend ID0
__IO_REG8(COMLBR3,    0x00023B, __READ_WRITE) // CAN0 local mask register B extend ID1
__IO_REG8(COMLBR4,    0x00023C, __READ_WRITE) // CAN0 local mask register B extend ID2
__IO_REG8(COSBS,      0x000240, __READ_WRITE) // CAN0 slot buffer select register
__IO_REG8(COCTLR1,    0x000241, __READ_WRITE) // CAN0 control register 1
__IO_REG8(COSLPR,     0x000242, __READ_WRITE) // CAN0 sleep control register
__IO_REG16(C0AFS,     0x000244, __READ_WRITE) // CAN0 acceptance filter support register

/************************  X-Y Control Register  **************************/
__IO_REG16( X0R,    0x0002C0, __READ_WRITE) // X0 register
__IO_REG16( X1R,    0x0002C2, __READ_WRITE) // X1 register
__IO_REG16( X2R,    0x0002C4, __READ_WRITE) // X2 register
__IO_REG16( X3R,    0x0002C6, __READ_WRITE) // X3 register
__IO_REG16( X4R,    0x0002C8, __READ_WRITE) // X4 register
__IO_REG16( X5R,    0x0002CA, __READ_WRITE) // X5 register
__IO_REG16( X6R,    0x0002CC, __READ_WRITE) // X6 register
__IO_REG16( X7R,    0x0002CE, __READ_WRITE) // X7 register
__IO_REG16( X8R,    0x0002D0, __READ_WRITE) // X8 register
__IO_REG16( X9R,    0x0002D2, __READ_WRITE) // X9 register
__IO_REG16( X10R,   0x0002D4, __READ_WRITE) // X10 register
__IO_REG16( X11R,   0x0002D6, __READ_WRITE) // X11 register
__IO_REG16( X12R,   0x0002D8, __READ_WRITE) // X12 register
__IO_REG16( X13R,   0x0002DA, __READ_WRITE) // X13 register
__IO_REG16( X14R,   0x0002DC, __READ_WRITE) // X14 register
__IO_REG16( X15R,   0x0002DE, __READ_WRITE) // X15 register
__IO_REG16( Y0R,    0x0002C0, __READ_WRITE) // Y0 register
__IO_REG16( Y1R,    0x0002C2, __READ_WRITE) // Y1 register
__IO_REG16( Y2R,    0x0002C4, __READ_WRITE) // Y2 register
__IO_REG16( Y3R,    0x0002C6, __READ_WRITE) // Y3 register
__IO_REG16( Y4R,    0x0002C8, __READ_WRITE) // Y4 register
__IO_REG16( Y5R,    0x0002CA, __READ_WRITE) // Y5 register
__IO_REG16( Y6R,    0x0002CC, __READ_WRITE) // Y6 register
__IO_REG16( Y7R,    0x0002CE, __READ_WRITE) // Y7 register
__IO_REG16( Y8R,    0x0002D0, __READ_WRITE) // Y8 register
__IO_REG16( Y9R,    0x0002D2, __READ_WRITE) // Y9 register
__IO_REG16( Y10R,   0x0002D4, __READ_WRITE) // Y10 register
__IO_REG16( Y11R,   0x0002D6, __READ_WRITE) // Y11 register
__IO_REG16( Y12R,   0x0002D8, __READ_WRITE) // Y12 register
__IO_REG16( Y13R,   0x0002DA, __READ_WRITE) // Y13 register
__IO_REG16( Y14R,   0x0002DC, __READ_WRITE) // Y14 register
__IO_REG16( Y15R,   0x0002DE, __READ_WRITE) // Y15 register
__IO_REG8(  XYC,    0x0002E0, __READ_WRITE) // XY control register

/************************  UART Registers  ********************************/
__IO_REG8( U0SMR,   0x000367, __READ_WRITE) // UART0 special mode register
__IO_REG8( U0SMR2,  0x000366, __READ_WRITE) // UART0 special mode register 2
__IO_REG8( U0SMR3,  0x000365, __READ_WRITE) // UART0 special mode register 3
__IO_REG8( U0SMR4,  0x000364, __READ_WRITE) // UART0 special mode register 4
__IO_REG8( U0MR,    0x000368, __READ_WRITE) // UART0 transmit-receive mode register
__IO_REG8( U0BRG,   0x000369, __READ_WRITE) // UART0 bit rate generator
__IO_REG8( U0C0,    0x00036C, __READ_WRITE) // UART0 transmit-receive control register 0
__IO_REG8( U0C1,    0x00036D, __READ_WRITE) // UART0 transmit-receive control register 1
__IO_REG8( U0TBL,   0x00036A, __READ_WRITE) // UART0 transmit buffer register, byte access
__IO_REG16(U0TB,    0x00036A, __READ_WRITE) // UART0 transmit buffer register
__IO_REG8( U0RBL,   0x00036E, __READ_WRITE) // UART0 receive buffer register, byte access 
__IO_REG16(U0RB,    0x00036E, __READ_WRITE) // UART0 receive buffer register

__IO_REG8( U1SMR,   0x0002E7, __READ_WRITE) // UART1 special mode register
__IO_REG8( U1SMR2,  0x0002E6, __READ_WRITE) // UART1 special mode register 2
__IO_REG8( U1SMR3,  0x0002E5, __READ_WRITE) // UART1 special mode register 3
__IO_REG8( U1SMR4,  0x0002E4, __READ_WRITE) // UART1 special mode register 4
__IO_REG8( U1MR,    0x0002E8, __READ_WRITE) // UART1 transmit-receive mode register
__IO_REG8( U1BRG,   0x0002E9, __READ_WRITE) // UART1 bit rate generator
__IO_REG8( U1C0,    0x0002EC, __READ_WRITE) // UART1 transmit-receive control register 0
__IO_REG8( U1C1,    0x0002ED, __READ_WRITE) // UART1 transmit-receive control register 1
__IO_REG8( U1TBL,   0x0002EA, __READ_WRITE) // UART1 transmit buffer register, byte access
__IO_REG16(U1TB,    0x0002EA, __READ_WRITE) // UART1 transmit buffer register
__IO_REG8( U1RBL,   0x0002EE, __READ_WRITE) // UART1 receive buffer register, byte access
__IO_REG16(U1RB,    0x0002EE, __READ_WRITE) // UART1 receive buffer register

__IO_REG8( U2SMR,   0x000337, __READ_WRITE) // UART2 special mode register
__IO_REG8( U2SMR2,  0x000336, __READ_WRITE) // UART2 special mode register 2
__IO_REG8( U2SMR3,  0x000335, __READ_WRITE) // UART2 special mode register 3
__IO_REG8( U2SMR4,  0x000334, __READ_WRITE) // UART2 special mode register 4
__IO_REG8( U2MR,    0x000338, __READ_WRITE) // UART2 transmit-receive mode register
__IO_REG8( U2GRG,   0x000339, __READ_WRITE) // UART2 bit rate generator
__IO_REG8( U2C0,    0x00033C, __READ_WRITE) // UART2 transmit-receive control register 0
__IO_REG8( U2C1,    0x00033D, __READ_WRITE) // UART2 transmit-receive control register 1
__IO_REG8( U2TBL,   0x00033A, __READ_WRITE) // UART2 transmit buffer register, byte access
__IO_REG16(U2TB,    0x00033A, __READ_WRITE) // UART2 transmit buffer register
__IO_REG8( U2RBL,   0x00033E, __READ_WRITE) // UART2 receive buffer register, byte access
__IO_REG16(U2RB,    0x00033E, __READ_WRITE) // UART2 receive buffer register

__IO_REG8( U3SMR,   0x000327, __READ_WRITE) // UART3 special mode register
__IO_REG8( U3SMR2,  0x000326, __READ_WRITE) // UART3 special mode register 2
__IO_REG8( U3SMR3,  0x000325, __READ_WRITE) // UART3 special mode register 3
__IO_REG8( U3SMR4,  0x000324, __READ_WRITE) // UART3 special mode register 4
__IO_REG8( U3MR,    0x000328, __READ_WRITE) // UART3 transmit-receive mode register
__IO_REG8( U3BRG,   0x000329, __READ_WRITE) // UART3 bit rate generator
__IO_REG8( U3C0,    0x00032C, __READ_WRITE) // UART3 transmit-receive control register 0
__IO_REG8( U3C1,    0x00032D, __READ_WRITE) // UART3 transmit-receive control register 1
__IO_REG8( U3TBL,   0x00032A, __READ_WRITE) // UART3 transmit buffer register, byte access
__IO_REG16(U3TB,    0x00032A, __READ_WRITE) // UART3 transmit buffer register
__IO_REG8( U3RBL,   0x00032E, __READ_WRITE) // UART3 receive buffer register, byte access
__IO_REG16(U3RB,    0x00032E, __READ_WRITE) // UART3 receive buffer register

__IO_REG8( U4SMR,   0x0002F7, __READ_WRITE) // UART4 special mode register
__IO_REG8( U4SMR2,  0x0002F6, __READ_WRITE) // UART4 special mode register 2
__IO_REG8( U4SMR3,  0x0002F5, __READ_WRITE) // UART4 special mode register 3
__IO_REG8( U4SMR4,  0x0002F4, __READ_WRITE) // UART4 special mode register 4
__IO_REG8( U4MR,    0x0002F8, __READ_WRITE) // UART4 transmit-receive mode register
__IO_REG8( U4BRG,   0x0002F9, __READ_WRITE) // UART4 bit rate generator
__IO_REG8( U4C0,    0x0002FC, __READ_WRITE) // UART4 transmit-receive control register 0
__IO_REG8( U4C1,    0x0002FD, __READ_WRITE) // UART4 transmit-receive control register 1
__IO_REG8( U4TBL,   0x0002FA, __READ_WRITE) // UART4 transmit buffer register, byte access
__IO_REG16(U4TB,    0x0002FA, __READ_WRITE) // UART4 transmit buffer register
__IO_REG8 (U4RBL,   0x0002FE, __READ_WRITE) // UART4 receive buffer register, byte access
__IO_REG16(U4RB,    0x0002FE, __READ_WRITE) // UART4 receive buffer register

/************************  Timer Registers  *******************************/
__IO_REG8( BTSR,    0x000164, __READ_WRITE) // Base timer start register
__IO_REG8( UBSR,    0x000300, __READ_WRITE) // Timer B3,B4,B5 count start flag
__IO_REG8( DTT,     0x00030C, __READ_WRITE) // Dead time timer
__IO_REG8( ICTB2,   0x00030D, __READ_WRITE) // Timer B2 interrupt occurence frequency set counter
__IO_REG8( TABSR,   0x000340, __READ_WRITE) // Count start flag
__IO_REG8( CPSRF,   0x000341, __READ_WRITE) // Clock prescaler reset flag
__IO_REG8( ONSF,    0x000342, __READ_WRITE) // One-shot start flag
__IO_REG8( TRGSR,   0x000343, __READ_WRITE) // Trigger select register
__IO_REG8( UDF,     0x000344, __READ_WRITE) // Up-down flag
__IO_REG8( TCSPR,   0x00035F, __READ_WRITE) // Count source prescaler register
__IO_REG8( INVC0,   0x000308, __READ_WRITE) // Three-phase PWM control register 0
__IO_REG8( INVC1,   0x000309, __READ_WRITE) // Three-phase PWM control register 1
__IO_REG8( IDB0,    0x00030A, __READ_WRITE) // Three-phase output buffer register 0
__IO_REG8( IDB1,    0x00030B, __READ_WRITE) // Three-phase output buffer register 1

__IO_REG16(TA0,     0x000346, __READ_WRITE) // Timer A0 register
__IO_REG8(TA0L,     0x000346, __READ_WRITE) // Timer A0 register (low byte)
__IO_REG8(TA0H,     0x000347, __READ_WRITE) // Timer A0 register (hight byte)
__IO_REG16(TA1,     0x000348, __READ_WRITE) // Timer A1 register
__IO_REG8(TA1L,     0x000348, __READ_WRITE) // Timer A1 register (low byte)
__IO_REG8(TA1H,     0x000349, __READ_WRITE) // Timer A1 register (hight byte)
__IO_REG16(TA11,    0x000302, __READ_WRITE) // Timer A1-1 register
__IO_REG8(TA11L,    0x000302, __READ_WRITE) // Timer A1-1 register (low byte)
__IO_REG8(TA11H,    0x000303, __READ_WRITE) // Timer A1-1 register (hight byte)
__IO_REG16(TA2,     0x00034A, __READ_WRITE) // Timer A2 register
__IO_REG8(TA2L,     0x00034A, __READ_WRITE) // Timer A2 register (low byte)
__IO_REG8(TA2H,     0x00034B, __READ_WRITE) // Timer A2 register (hight byte)
__IO_REG16(TA21,    0x000304, __READ_WRITE) // Timer A2-1 register
__IO_REG8(TA21L,    0x000304, __READ_WRITE) // Timer A2-1 register (low byte)
__IO_REG8(TA21H,    0x000305, __READ_WRITE) // Timer A2-1 register (hight byte)
__IO_REG16(TA3,     0x00034C, __READ_WRITE) // Timer A3 register
__IO_REG8(TA3L,     0x00034C, __READ_WRITE) // Timer A3 register (low byte)
__IO_REG8(TA3H,     0x00034D, __READ_WRITE) // Timer A3 register (hight byte)
__IO_REG16(TA4,     0x00034E, __READ_WRITE) // Timer A4 register
__IO_REG8(TA4L,     0x00034E, __READ_WRITE) // Timer A4 register (low byte)
__IO_REG8(TA4H,     0x00034F, __READ_WRITE) // Timer A4 register (hight byte)
__IO_REG16(TA41,    0x000306, __READ_WRITE) // Timer A4-1 register
__IO_REG8(TA41L,    0x000306, __READ_WRITE) // Timer A4-1 register (low byte)
__IO_REG8(TA41H,    0x000307, __READ_WRITE) // Timer A4-1 register (hight byte)
__IO_REG16(TB0,     0x000350, __READ_WRITE) // Timer B0 register
__IO_REG8(TB0L,     0x000350, __READ_WRITE) // Timer B0 register (low byte)
__IO_REG8(TB0H,     0x000351, __READ_WRITE) // Timer B0 register (hight byte)
__IO_REG16(TB1,     0x000352, __READ_WRITE) // Timer B1 register
__IO_REG8(TB1L,     0x000352, __READ_WRITE) // Timer B1 register (low byte)
__IO_REG8(TB1H,     0x000353, __READ_WRITE) // Timer B1 register (hight byte)
__IO_REG16(TB2,     0x000354, __READ_WRITE) // Timer B2 register
__IO_REG8(TB2L,     0x000354, __READ_WRITE) // Timer B2 register (low byte)
__IO_REG8(TB2H,     0x000355, __READ_WRITE) // Timer B2 register (hight byte)
__IO_REG16(TB3,     0x000310, __READ_WRITE) // Timer B3 register
__IO_REG8(TB3L,     0x000310, __READ_WRITE) // Timer B3 register (low byte)
__IO_REG8(TB3H,     0x000311, __READ_WRITE) // Timer B3 register (hight byte)
__IO_REG16(TB4,     0x000312, __READ_WRITE) // Timer B4 register
__IO_REG8(TB4L,     0x000312, __READ_WRITE) // Timer B4 register (low byte)
__IO_REG8(TB4H,     0x000313, __READ_WRITE) // Timer B4 register (hight byte)
__IO_REG16(TB5,     0x000314, __READ_WRITE) // Timer B5 register
__IO_REG8(TB5L,     0x000314, __READ_WRITE) // Timer B5 register (low byte)
__IO_REG8(TB5H,     0x000315, __READ_WRITE) // Timer B5 register (hight byte)

__IO_REG8( TA0MR,   0x000356, __READ_WRITE) // Timer A0 mode register
__IO_REG8( TA1MR,   0x000357, __READ_WRITE) // Timer A1 mode register
__IO_REG8( TA2MR,   0x000358, __READ_WRITE) // Timer A2 mode register
__IO_REG8( TA3MR,   0x000359, __READ_WRITE) // Timer A3 mode register
__IO_REG8( TA4MR,   0x00035A, __READ_WRITE) // Timer A4 mode register
__IO_REG8( TB0MR,   0x00035B, __READ_WRITE) // Timer B0 mode register
__IO_REG8( TB1MR,   0x00035C, __READ_WRITE) // Timer B1 mode register
__IO_REG8( TB2MR,   0x00035D, __READ_WRITE) // Timer B2 mode register
__IO_REG8( TB2SC,   0x00035E, __READ_WRITE) // Timer B2 special mode register
__IO_REG8( TB3MR,   0x00031B, __READ_WRITE) // Timer B3 mode register
__IO_REG8( TB4MR,   0x00031C, __READ_WRITE) // Timer B4 mode register
__IO_REG8( TB5MR,   0x00031D, __READ_WRITE) // Timer B5 mode register

/************************  DMA Registers  *********************************/
__IO_REG8( DM0SL,   0x000378, __READ_WRITE) // DMA0 cause select register
__IO_REG8( DM1SL,   0x000379, __READ_WRITE) // DMA1 cause select register
__IO_REG8( DM2SL,   0x00037A, __READ_WRITE) // DMA2 cause select register
__IO_REG8( DM3SL,   0x00037B, __READ_WRITE) // DMA3 cause select register

/************************  CRC register  **********************************/
__IO_REG16(CRCD,    0x00037C, __READ_WRITE) // CRC data register
__IO_REG8( CRCIN,   0x00037E, __READ_WRITE) // CRC input register

/************************  Port Registers  ********************************/
__IO_REG8( PS0,     0x0003B0, __READ_WRITE) // Function select register A0
__IO_REG8( PS1,     0x0003B1, __READ_WRITE) // Function select register A1
__IO_REG8( PS2,     0x0003B4, __READ_WRITE) // Function select register A2
__IO_REG8( PS3,     0x0003B5, __READ_WRITE) // Function select register A3
__IO_REG8( PS5,     0x0003B9, __READ_WRITE) // Function select register A5
__IO_REG8( PS6,     0x0003BC, __READ_WRITE) // Function select register A6
__IO_REG8( PS7,     0x0003BD, __READ_WRITE) // Function select register A7
__IO_REG8( PS8,     0x0003A0, __READ_WRITE) // Function select register A8
__IO_REG8( PS9,     0x0003A1, __READ_WRITE) // Function select register A9
__IO_REG8( PSL0,    0x0003B2, __READ_WRITE) // Function select register B0
__IO_REG8( PSL1,    0x0003B3, __READ_WRITE) // Function select register B1
__IO_REG8( PSL2,    0x0003B6, __READ_WRITE) // Function select register B2
__IO_REG8( PSL3,    0x0003B7, __READ_WRITE) // Function select register B3
__IO_REG8( PSC,     0x0003AF, __READ_WRITE) // Function select register C

__IO_REG8( P0,      0x0003E0, __READ_WRITE) // Port P0 register
__IO_REG8( PD0,     0x0003E2, __READ_WRITE) // Port P0 direction register
__IO_REG8( P1,      0x0003E1, __READ_WRITE) // Port P1 register
__IO_REG8( PD1,     0x0003E3, __READ_WRITE) // Port P1 direction register
__IO_REG8( P2,      0x0003E4, __READ_WRITE) // Port P2 register
__IO_REG8( PD2,     0x0003E6, __READ_WRITE) // Port P2 direction register
__IO_REG8( P3,      0x0003E5, __READ_WRITE) // Port P3 register
__IO_REG8( PD3,     0x0003E7, __READ_WRITE) // Port P3 direction register
__IO_REG8( P4,      0x0003E8, __READ_WRITE) // Port P4 register
__IO_REG8( PD4,     0x0003EA, __READ_WRITE) // Port P4 direction register
__IO_REG8( P5,      0x0003E9, __READ_WRITE) // Port P5 register
__IO_REG8( PD5,     0x0003EB, __READ_WRITE) // Port P5 direction register
__IO_REG8( P6,      0x0003C0, __READ_WRITE) // Port P6 register
__IO_REG8( PD6,     0x0003C2, __READ_WRITE) // Port P6 direction register
__IO_REG8( P7,      0x0003C1, __READ_WRITE) // Port P7 register
__IO_REG8( PD7,     0x0003C3, __READ_WRITE) // Port P7 direction register
__IO_REG8( P8,      0x0003C4, __READ_WRITE) // Port P8 register
__IO_REG8( PD8,     0x0003C6, __READ_WRITE) // Port P8 direction register
__IO_REG8( P9,      0x0003C5, __READ_WRITE) // Port P9 register
__IO_REG8( PD9,     0x0003C7, __READ_WRITE) // Port P9 direction register
__IO_REG8( P10,     0x0003C8, __READ_WRITE) // Port P10 register
__IO_REG8( PD10,    0x0003CA, __READ_WRITE) // Port P10 direction register
__IO_REG8( P11,     0x0003C9, __READ_WRITE) // Port P11 register
__IO_REG8( PD11,    0x0003CB, __READ_WRITE) // Port P11 direction register
__IO_REG8( P12,     0x0003CC, __READ_WRITE) // Port P12 register
__IO_REG8( PD12,    0x0003CE, __READ_WRITE) // Port P12 direction register
__IO_REG8( P13,     0x0003CD, __READ_WRITE) // Port P13 register
__IO_REG8( PD13,    0x0003CF, __READ_WRITE) // Port P13 direction register
__IO_REG8( P14,     0x0003D0, __READ_WRITE) // Port P14 register
__IO_REG8( PD14,    0x0003D2, __READ_WRITE) // Port P14 direction register
__IO_REG8( P15,     0x0003D1, __READ_WRITE) // Port P15 register
__IO_REG8( PD15,    0x0003D3, __READ_WRITE) // Port P15 direction register

__IO_REG8( PUR0,    0x0003F0, __READ_WRITE) // Pull-upp control register 0
__IO_REG8( PUR1,    0x0003F1, __READ_WRITE) // Pull-upp control register 1
__IO_REG8( PUR2,    0x0003DA, __READ_WRITE) // Pull-upp control register 2
__IO_REG8( PUR3,    0x0003DB, __READ_WRITE) // Pull-upp control register 3
__IO_REG8( PUR4,    0x0003DC, __READ_WRITE) // Pull-upp control register 4
__IO_REG8( PCR,     0x0003FF, __READ_WRITE) // Port control register

#pragma language=default

#endif /* __IOM32C_H__ */
